@@ -154,7 +154,7 @@ class HttpConnection(AbstractConnection):
         self._page_size = config.get("page_size")
 
         assert self._user
-        assert self._pwd
+        # assert self._pwd
 
         self._conn = requests.Session()            # 创建一个session对象，requests库的session对象还能提供请求方法的缺省数据，通过设置session对象的属性来实现
         self._status = ConnectionStatus.Connected         #调common中的连接状态码，状态设为已连接
@@ -186,9 +186,17 @@ class HttpConnection(AbstractConnection):
                 method_data = kwargs.get("http_method", "POST")
                 if method_data.upper() == "POST":
                     header = {
-                        "Application-Token": self._pwd,
+                        "Application-Token": self._pwd
                     }
                     response = self._conn.post(url, headers=header, json=params, timeout=self._timeout)
+                    rsp = response.json()
+                    if "error_code" in rsp:
+                        if int(rsp["error_code"])==100006:
+                            header = {
+                                "Content-Type": "application/x-www-form-urlencoded",
+                                "Application-Token": self._pwd
+                            }
+                            response = self._conn.get(url, headers=header, params=params, timeout=self._timeout)
                 else:
                     header = {
                         "Content-Type": "application/x-www-form-urlencoded",
